@@ -2,8 +2,7 @@
  *
  * CLEX File Manager
  *
- * Copyright (C) 1997-2000 Tempest s.r.o. http://www.tempest.sk
- * Copyright (C) 2001-2004 Vlado Potisk <vlado_potisk@clex.sk>
+ * Copyright (C) 2001-2005 Vlado Potisk <vlado_potisk@clex.sk>
  *
  * CLEX is free software without warranty of any kind; see the
  * GNU General Public License as set out in the "COPYING" document
@@ -86,7 +85,7 @@ static CNUM table_numeric[] = {
 	{ CFG_FRAME,		0, 0, 2, 0, 0, 0,
 		{	"-----",
 			"=====",
-			"line graphics (might not work properly)" } },
+			"line graphics (not supported on some terminals)" } },
 	{ CFG_GROUP_FILES,	0, 0, 2, 2, 0, 0,
 		{	"Do not group",
 			"Group: directories, special files, plain files",
@@ -96,9 +95,6 @@ static CNUM table_numeric[] = {
 		{	"Layout #1",
 			"Layout #2",
 			"Layout #3" } },
-	{ CFG_SHOW_HIDDEN,	0, 0, 1, 1, 0, 0,
-		{	"Show all files except hidden .files",
-			"Show all files (recommended)" } },
 	{ CFG_WARN_RM,		0, 0, 1, 1, 0, 0, { "No", "Yes" } },
 	{ CFG_WARN_LONG,	0, 0, 1, 1, 0, 0, { "No", "Yes" } },
 	{ CFG_WARN_SELECT,	0, 0, 1, 1, 0, 0, { "No", "Yes" } },
@@ -184,8 +180,6 @@ static struct {
 						"see help" },
 	{ CFG_SHELLPROG,	"Shell program, see help "
 						"(AUTO = your login shell)" },
-	{ CFG_SHOW_HIDDEN,	"Appearance: "
-		"Show hidden files (filename begins with a dot)" },
 	{ CFG_WARN_RM,		"Warn before executing 'rm' (remove) command" },
 	{ CFG_WARN_LONG,	"Warn that the command line is too long to be "
 						"displayed" },
@@ -199,7 +193,6 @@ static CONFIG_ENTRY config[] = {
 	{ "CMD_LINES",		0,0,0,0,0 },
 	{ "XTERM_TITLE",	0,0,0,0,0 },
 	{ "GROUP_FILES",	0,0,0,0,0 },
-	{ "SHOW_HIDDEN",	0,0,0,0,0 },
 	{ "PROMPT",			0,0,0,0,0 },
 	{ "LAYOUT1",		0,0,0,0,0 },
 	{ "LAYOUT2",		0,0,0,0,0 },
@@ -460,30 +453,6 @@ config_initialize(void)
 {
 	int i, fd;
 
-	static const char *menu[] = {
-		"continue:    continue configuring",
-		"CANCEL:      no configuration change",
-		"ACCEPT:      use the new configuration in this session",
-		"ACCEPT+SAVE: save the configuration to ~/.clexrc"
-	};
-	static const char *admin_menu[] = {
-		"continue:   continue configuring",
-		"QUIT:       no configuration change",
-		"SAVE+QUIT:  save the new system-wide defaults to " CONFIG_FILE
-	};
-
-	if (clex_data.admin) {
-		panel_cfg_confirm.menu = admin_menu;
-		panel_cfg_confirm.pd->cnt = ARRAY_SIZE(admin_menu);
-	}
-	else {
-		panel_cfg_confirm.menu = menu;
-		panel_cfg_confirm.pd->cnt = ARRAY_SIZE(menu);
-	}
-
-	panel_cfg.pd->cnt = ARRAY_SIZE(config);
-	panel_cfg.config = config;
-
 	/* initialize 'config' table */
 	for (i = 0; i < ARRAY_SIZE(config); i++) {
 		if ( (config[i].table = get_numeric(i)) )
@@ -497,6 +466,7 @@ config_initialize(void)
 	}
 
 	if (clex_data.admin) {
+		panel_cfg.extra_lines = 2;
 		/*
 		 * check user's access rights
 		 * this may create an empty file, never mind
@@ -517,6 +487,7 @@ config_initialize(void)
 		read_configuration(CONFIG_FILE,0);
 	}
 	else {
+		panel_cfg.extra_lines = 3;
 		/* user's configuration file name */
 		pathname_set_directory(clex_data.homedir);
 		user_config_file = estrdup(pathname_join(".clexrc"));
@@ -527,6 +498,9 @@ config_initialize(void)
 			set_value(i,MOV_I2C);
 		read_configuration(user_config_file,0);
 	}
+
+	panel_cfg.pd->cnt = panel_cfg.extra_lines + ARRAY_SIZE(config);
+	panel_cfg.config = config;
 }
 
 int
@@ -632,62 +606,31 @@ config_prepare(void)
 {
 	int i;
 
-	if (!TCLR(panel_cfg.no_init)) {
-		for (i = 0; i < ARRAY_SIZE(config); i++)
-			set_value(i,MOV_C2N);
-		panel_cfg.pd->top = panel_cfg.pd->curs = -1;
-	}
+	for (i = 0; i < ARRAY_SIZE(config); i++)
+		set_value(i,MOV_C2N);
+	panel_cfg.pd->top = panel_cfg.pd->curs = 0;
 	panel = panel_cfg.pd;
 	textline = 0;
 }
 
-void
-config_confirm_prepare(void)
-{
-	int i;
-	FLAG changed;
-	CNUM *pnum;
-	CSTR *pstr;
-
-	for (changed = 0, i = 0; i < ARRAY_SIZE(config); i++) {
-		if (config[i].isnum) {
-			pnum = config[i].table;
-			config[i].changed = pnum->new != pnum->current;
-			config[i].saveit = pnum->new != pnum->initial;
-		}
-		else {
-			pstr = config[i].table;
-			config[i].changed = strcmp(pstr->new,pstr->current) != 0;
-			config[i].saveit = strcmp(pstr->new,pstr->initial) != 0;
-		}
-		if (config[i].changed)
-			changed = 1;
-	}
-
-	panel_cfg_confirm.pd->top = 0;
-	panel_cfg_confirm.pd->curs = 0;	/* CANCEL line */
-	panel = panel_cfg_confirm.pd;
-	textline = 0;
-	if (!changed)
-		win_remark("configuration was not changed");
-}
-
 void
 config_edit_num_prepare(void)
 {
 	static char prompt[CFGVAR_LEN + 48];
 	CNUM *pnum;
+	int param;
 
-	pnum = config[panel_cfg.pd->curs].table;
+	param = panel_cfg.pd->curs - panel_cfg.extra_lines;
+	pnum = config[param].table;
 	
 	textline = &line_tmp;
 	sprintf(prompt,"%s (range: %d - %d%s%s): ",
-	  config[panel_cfg.pd->curs].var,pnum->min,pnum->max,
+	  config[param].var,pnum->min,pnum->max,
 	  pnum->extra_val != 0 ? " or " : "",
 	  pnum->extra_val != 0 ? pnum->extra_val : "");
 	edit_setprompt(textline,prompt);
 
-	edit_nu_putstr(config_print_value(panel_cfg.pd->curs));
+	edit_nu_putstr(config_print_value(param));
 	edit_adjust();
 }
 
@@ -696,51 +639,29 @@ config_edit_str_prepare(void)
 {
 	static char prompt[CFGVAR_LEN + 32];
 	CSTR *pstr;
+	int param;
 
-	pstr = config[panel_cfg.pd->curs].table;
+	param = panel_cfg.pd->curs - panel_cfg.extra_lines;
+	pstr = config[param].table;
 
 	textline = &line_tmp;
 	sprintf(prompt,"%s (%d chars max%s%s): ",
-	  config[panel_cfg.pd->curs].var,CFGVALUE_LEN,
+	  config[param].var,CFGVALUE_LEN,
 	  pstr->extra_val != 0 ? " or " : "",
 	  pstr->extra_val != 0 ? pstr->extra_val : "");
 	edit_setprompt(textline,prompt);
 
-	edit_nu_putstr(config_print_value(panel_cfg.pd->curs));
+	edit_nu_putstr(config_print_value(param));
 	edit_adjust();
 }
-
-void
-cx_config_edit(void)
-{
-	CNUM *pnum;
-
-	if (panel_cfg.pd->curs < 0) {
-		next_mode = MODE_CFG_CONFIRM;
-		return;
-	}
-
-	if (config[panel_cfg.pd->curs].isnum) {
-		pnum = config[panel_cfg.pd->curs].table;
-		if (pnum->desc[0]) {
-			if (++pnum->new > pnum->max)
-				pnum->new = pnum->min;
-		}
-		else
-			control_loop(MODE_CFG_EDIT_NUM);
-	}
-	else
-		control_loop(MODE_CFG_EDIT_TXT);
-	win_panel_opt();
-}
-
 void
 cx_config_num_enter(void)
 {
-	int nvalue, ilen;
+	int nvalue, ilen, param;
 	CNUM *pnum;
 
-	pnum = config[panel_cfg.pd->curs].table;
+	param = panel_cfg.pd->curs - panel_cfg.extra_lines;
+	pnum = config[param].table;
 	if (pnum->extra_val != 0
 	  && strcmp(USTR(textline->line),pnum->extra_val) == 0) {
 		pnum->new = 0;
@@ -763,8 +684,10 @@ void
 cx_config_str_enter(void)
 {
 	CSTR *pstr;
+	int param;
 
-	pstr = config[panel_cfg.pd->curs].table;
+	param = panel_cfg.pd->curs - panel_cfg.extra_lines;
+	pstr = config[param].table;
 	if (pstr->extra_val != 0
 	  && strcmp(USTR(textline->line),pstr->extra_val) == 0) {
 		*pstr->new = '\0';
@@ -783,19 +706,46 @@ cx_config_str_enter(void)
 void
 cx_config_default(void)
 {
-	if (panel_cfg.pd->curs < 0)
-		return;
-	set_value(panel_cfg.pd->curs,MOV_I2N);
-	win_panel_opt();
+	int param;
+
+	param = panel_cfg.pd->curs - panel_cfg.extra_lines;
+	if (param >= 0) {
+		set_value(param,MOV_I2N);
+		win_panel_opt();
+	}
 }
 
 void
 cx_config_original(void)
 {
-	if (panel_cfg.pd->curs < 0)
-		return;
-	set_value(panel_cfg.pd->curs,MOV_C2N);
-	win_panel_opt();
+	int param;
+
+	param = panel_cfg.pd->curs - panel_cfg.extra_lines;
+	if (param >= 0) {
+		set_value(param,MOV_C2N);
+		win_panel_opt();
+	}
+}
+
+/* detect what has changed */
+static void
+config_changes(void)
+{
+	int i;
+	CNUM *pnum;
+	CSTR *pstr;
+
+	for (i = 0; i < ARRAY_SIZE(config); i++)
+		if (config[i].isnum) {
+			pnum = config[i].table;
+			config[i].changed = pnum->new != pnum->current;
+			config[i].saveit = pnum->new != pnum->initial;
+		}
+		else {
+			pstr = config[i].table;
+			config[i].changed = strcmp(pstr->new,pstr->current) != 0;
+			config[i].saveit = strcmp(pstr->new,pstr->initial) != 0;
+		}
 }
 
 static void
@@ -814,7 +764,7 @@ config_apply(void)
 		win_frame();
 	}
 	if (config[CFG_CMD_LINES].changed)
-		/* all it takes is to say it ... */
+		/* all it takes is to say it ... isn't it magic ?! */
 		txt_printf("SCREEN: changing geometry\n");
 	if (config[CFG_XTERM_TITLE].changed) {
 		xterm_title_restore();
@@ -833,8 +783,7 @@ config_apply(void)
 		win_layout_reconfig();
 		reread = 1;
 	}
-	if (config[CFG_SHOW_HIDDEN].changed
-	  || config[CFG_FMT_NUMBER].changed
+	if (config[CFG_FMT_NUMBER].changed
 	  || config[CFG_FMT_TIME].changed
 	  || config[CFG_FMT_DATE].changed)
 		reread = 1;
@@ -877,32 +826,43 @@ config_apply(void)
 }
 
 void
-cx_config_confirm(void)
+cx_config_edit(void)
 {
-	int fn;
+	CNUM *pnum;
+	int param;
 
-	/* admin:  0 = CONTINUE, 1 = CANCEL, 2 = SAVE */
-	/* config: 0 = CONTINUE, 1 = CANCEL, 2 = ACCEPT, 3 = SAVE */
-	fn = panel_cfg_confirm.pd->curs;
-
-	if (fn == 0) {
-		panel_cfg.no_init = 1;
-		next_mode = MODE_CFG;
-		return;
+	if (panel_cfg.pd->curs < panel_cfg.extra_lines) {
+		if (clex_data.admin) {
+			/* admin mode:  0 = CANCEL, 1 = SAVE */
+			if (panel_cfg.pd->curs == 1) {
+				config_changes();
+				config_save();
+			}
+			next_mode = MODE_SPECIAL_QUIT;
+		}
+		else {
+			/* normal config: 0 = CANCEL, 1 = ACCEPT, 2 = SAVE */
+			if (panel_cfg.pd->curs >= 1) {
+				config_changes();
+				config_apply();
+				if (param == 2)
+					config_save();
+			}
+			next_mode = MODE_SPECIAL_RETURN;
+		}
+	} else {
+		param = panel_cfg.pd->curs - panel_cfg.extra_lines;
+		if (config[param].isnum) {
+			pnum = config[param].table;
+			if (pnum->desc[0]) {
+				if (++pnum->new > pnum->max)
+					pnum->new = pnum->min;
+			}
+			else
+				control_loop(MODE_CFG_EDIT_NUM);
+		}
+		else
+			control_loop(MODE_CFG_EDIT_TXT);
+		win_panel_opt();
 	}
-
-	if (clex_data.admin) {
-		if (fn == 2)
-			config_save();
-		next_mode = MODE_SPECIAL_QUIT;
-		return;
-	}
-
-	if (fn == 2)
-		config_apply();
-	else if (fn == 3) {
-		config_apply();
-		config_save();
-	}
-	next_mode = MODE_SPECIAL_RETURN;
 }
