@@ -2,8 +2,7 @@
  *
  * CLEX File Manager
  *
- * Copyright (C) 1997-2000 Tempest s.r.o. http://www.tempest.sk
- * Copyright (C) 2001-2004 Vlado Potisk <vlado_potisk@clex.sk>
+ * Copyright (C) 2001-2005 Vlado Potisk <vlado_potisk@clex.sk>
  *
  * CLEX is free software without warranty of any kind; see the
  * GNU General Public License as set out in the "COPYING" document
@@ -145,19 +144,17 @@ cx_edit_right(void)
 void
 cx_edit_up(void)
 {
-	if (textline->curs >= display.scrcols) {
-		textline->curs -= display.scrcols;
-		edit_update_cursor();
-	}
+	textline->curs -= display.scrcols;
+	LIMIT_MIN(textline->curs,0);
+	edit_update_cursor();
 }
 
 void
 cx_edit_down(void)
 {
-	if (textline->size - textline->curs >= display.scrcols) {
-		textline->curs += display.scrcols;
-		edit_update_cursor();
-	}
+	textline->curs += display.scrcols;
+	LIMIT_MAX(textline->curs,textline->size);
+	edit_update_cursor();
 }
 
 /* move one word left */
