@@ -2,8 +2,7 @@
  *
  * CLEX File Manager
  *
- * Copyright (C) 1997-2000 Tempest s.r.o. http://www.tempest.sk
- * Copyright (C) 2001-2004 Vlado Potisk <vlado_potisk@clex.sk>
+ * Copyright (C) 2001-2005 Vlado Potisk <vlado_potisk@clex.sk>
  *
  * CLEX is free software without warranty of any kind; see the
  * GNU General Public License as set out in the "COPYING" document
@@ -45,17 +44,13 @@ files_initialize(void)
 	const char *dir2;
 	static PANEL_DESC panel_desc_1 = { 0,0,0,0,PANEL_TYPE_FILE,0,1 };
 	static PANEL_DESC panel_desc_2 = { 0,0,0,0,PANEL_TYPE_FILE,0,1 };
-	static PANEL_FILE panel_f1 = { &panel_desc_1 };
-	static PANEL_FILE panel_f2 = { &panel_desc_2 };
+	static PANEL_FILE panel_f1 =
+		{ &panel_desc_1, { 0,0 }, 0,0,1,0,0 };
+	static PANEL_FILE panel_f2 =
+		{ &panel_desc_2, { 0,0 }, 0,0,1,0,0 };
 
-	US_INIT(panel_f1.dir);
 	if (get_cwd_us(&panel_f1.dir) < 0)
 		err_exit("Cannot get the name of the working directory");
-	panel_f1.fe_alloc = 0;
-	panel_f1.files = 0;
-	panel_f1.other = &panel_f2;
-
-	US_INIT(panel_f2.dir);
 	dir2 = config_str(CFG_DIR2);
 	if (*dir2 != '/') {
 		dir2 = clex_data.homedir;
@@ -63,11 +58,8 @@ files_initialize(void)
 			dir2 = USTR(panel_f1.dir);
 	}
 	us_copy(&panel_f2.dir,dir2);
-	panel_f2.fe_alloc = 0;
-	panel_f2.files = 0;
-	panel_f2.other = &panel_f1;
-
-	ppanel_file = &panel_f1;
+	panel_f1.other = &panel_f2;
+	ppanel_file = panel_f2.other = &panel_f1;
 }
 
 void
@@ -85,12 +77,6 @@ files_main_prepare(void)
 	textline = &line_cmd;
 	edit_nu_kill();
 
-	ppanel_file->pd->cnt = 0;
-	ppanel_file->expired = 1;
-
-	ppanel_file->other->pd->cnt = 0;
-	ppanel_file->other->expired = 1;
-
 	panel = ppanel_file->pd;
 	list_directory();
 }
@@ -116,10 +102,10 @@ find_valid_cwd(void)
 {
 	char *dir, *p;
 
-	win_warning("CHDIR: panel's directory is not accessible "
+	win_warning("CHANGE DIR: panel's directory is not accessible "
 	  "and will be changed");
 
-	ppanel_file->pd->cnt = 0;
+	ppanel_file->pd->cnt = ppanel_file->selected = 0;
 
 	dir = USTR(ppanel_file->dir);
 	for (p = dir + strlen(dir); p > dir ; p--)
@@ -158,7 +144,7 @@ changedir_error(int errcode)
 	default:
 		msg = "Cannot change directory";
 	}
-	win_warning_fmt("CHDIR: %s.",msg);
+	win_warning_fmt("CHANGE DIR: %s.",msg);
 }
 
 /*
@@ -197,7 +183,7 @@ changedir(const char *dir)
 
 	if (strcmp(USTR(savedir),USTR(ppanel_file->dir)))
 		/* panel contents is invalid in different directory */
-		ppanel_file->pd->cnt = 0;
+		ppanel_file->pd->cnt = ppanel_file->selected = 0;
 	list_directory();
 
 	/*
