@@ -2,8 +2,7 @@
  *
  * CLEX File Manager
  *
- * Copyright (C) 1997-2000 Tempest s.r.o. http://www.tempest.sk
- * Copyright (C) 2001-2004 Vlado Potisk <vlado_potisk@clex.sk>
+ * Copyright (C) 2001-2005 Vlado Potisk <vlado_potisk@clex.sk>
  *
  * CLEX is free software without warranty of any kind; see the
  * GNU General Public License as set out in the "COPYING" document
@@ -65,12 +64,8 @@ hist_prepare(void)
 {
 	panel_hist.pd->top = -1;
 	panel_hist.pd->cnt = hs_cnt;
-	if (pn_index >= 0) {
-		panel_hist.pd->curs = pn_index;
-		pan_adjust(panel_hist.pd);
-	}
-	else
-		panel_hist.pd->curs = 0;
+	panel_hist.pd->curs = pn_index >= 0 ? pn_index : 0;
+	pan_adjust(panel_hist.pd);
 
 	panel = panel_hist.pd;
 	textline = &line_cmd;
@@ -204,3 +199,33 @@ cx_hist_enter(void)
 		textline->undo_possible = 0;
 	}
 }
+
+void
+cx_hist_del(void)
+{
+	int i, del;
+	HIST_ENTRY *x;
+
+	if ( (del = panel_hist.pd->curs) < 0) {
+		win_remark("cannot delete");
+		return;
+	}
+
+	panel_hist.pd->cnt = --hs_cnt;
+	if (panel_hist.pd->curs == panel_hist.pd->cnt) {
+		panel_hist.pd->curs--;
+		pan_adjust(panel_hist.pd);
+	}
+
+	x = HS_LIST[del];
+	for (i = del; i < hs_cnt; i++)
+		HS_LIST[i] = HS_LIST[i + 1];
+	HS_LIST[hs_cnt] = x;
+
+	if (pn_index > del)
+		pn_index--;
+	else if (pn_index == del)
+		hist_reset_index();
+
+	win_panel();
+}
