@@ -2,8 +2,7 @@
  *
  * CLEX File Manager
  *
- * Copyright (C) 1997-2000 Tempest s.r.o. http://www.tempest.sk
- * Copyright (C) 2001-2004 Vlado Potisk <vlado_potisk@clex.sk>
+ * Copyright (C) 2001-2005 Vlado Potisk <vlado_potisk@clex.sk>
  *
  * CLEX is free software without warranty of any kind; see the
  * GNU General Public License as set out in the "COPYING" document
@@ -608,9 +607,6 @@ win_heading(void)
 	case MODE_CFG_EDIT_TXT:
 		msg = "CONFIGURATION > NEW VALUE";
 		break;
-	case MODE_CFG_CONFIRM:
-		msg = "CONFIGURATION > CONFIRM CHANGES";
-		break;
 	case MODE_COMPARE:
 		msg = "DIRECTORY COMPARE";
 		break;
@@ -632,7 +628,7 @@ win_heading(void)
 		break;
 	case MODE_HIST:
 		msg = "COMMAND HISTORY    "
-		  "[ <tab> = insert, <enter> = execute ]";
+		  "[ <tab> = insert, <enter> = execute, <del> = delete ]";
 		break;
 	case MODE_P_LOCATE:
 	case MODE_S_LOCATE:
@@ -643,8 +639,7 @@ win_heading(void)
 		break;
 	case MODE_SELECT:
 	case MODE_DESELECT:
-		msg = "DESELECT FILES    "
-		  " [ ctrl-P/ctrl-N = browse history list ]";
+		msg = "DESELECT FILES";
 		if (mode == MODE_SELECT)
 			msg +=2;	/* DESELECT... --> SELECT ... */
 		break;
@@ -805,8 +800,16 @@ print_fields(FILE_ENTRY *pfe, int width, const char *fields)
 static void
 win_info(void)
 {
+	static const char *cfg_normal_infoline[] = {
+		"No configuration change",
+		"Use the new configuration in this session",
+		"Save the configuration to ~/.clexrc"
+	}, *cfg_admin_infoline[] = {
+		"No configuration change",
+		"Save the new system-wide defaults to " CONFIG_FILE
+	};
 	int width;
-	const char *aux;
+	const char *msg;
 	FILE_ENTRY *pfe;
 
 	move(display.panlines + 3,0);
@@ -840,15 +843,20 @@ win_info(void)
 
 	if (panel->type == PANEL_TYPE_CFG) {
 		addstr("  ");					/* 2 */
-		putstr_trunc(panel_cfg.config[panel->curs].help,
-		  display.scrcols - 2,0);
+		if (panel->curs < panel_cfg.extra_lines)
+			msg = (clex_data.admin ? cfg_admin_infoline
+			  : cfg_normal_infoline)[panel->curs];
+		else
+			msg = panel_cfg.config[panel->curs
+			  - panel_cfg.extra_lines].help;
+		putstr_trunc(msg,display.scrcols - 2,0);
 		return;
 	}
 
 	if (panel->type == PANEL_TYPE_COMPL) {
-		if ( (aux = panel_compl.candidate[panel->curs].aux) ) {
+		if ( (msg = panel_compl.candidate[panel->curs].aux) ) {
 			addstr("  ");				/* 2 */
-			putstr_trunc(aux,display.scrcols - 2,0);
+			putstr_trunc(msg,display.scrcols - 2,0);
 			return;
 		}
 		clrtoeol();
@@ -1073,11 +1081,22 @@ draw_line_compl(int ln)
 static void
 draw_line_conf(int ln)
 {
-	putstr_trunc(panel_cfg.config[ln].var,
-	  CFGVAR_LEN,0);		/* CFGVAR_LEN */
-	addstr(" = ");			/* 3 */
-	putstr_trunc(config_print_value(ln),
-	  display.pancols - CFGVAR_LEN - 3,0);
+
+	static const char
+	  *normal_menu[] = { "Cancel", "Accept", "Accept+Save" },
+	  *admin_menu[] = { "Cancel+Quit", "Save+Quit" };
+
+	if (ln < panel_cfg.extra_lines) {
+		addstr(" -> ");			/* 4 */
+		putstr_trunc((clex_data.admin ? admin_menu : normal_menu)[ln],
+		  display.pancols - 4,0);
+	} else {
+		ln -= panel_cfg.extra_lines;
+		putstr_trunc(panel_cfg.config[ln].var,CFGVAR_LEN,0);
+		addstr(" = ");			/* 3 */
+		putstr_trunc(config_print_value(ln),
+		  display.pancols - CFGVAR_LEN - 3,0);
+	}
 }
 
 static void
@@ -1136,24 +1155,24 @@ static void
 draw_line_mainmenu(int ln)
 {
 	static const char *description[] = {
-		"on-line help                             <F1> ",
+		"help                                     <F1> ",
 		"change working directory                 <esc> D",
 		"  change into root directory             <esc> /",
 		"  change into parent directory           <esc> .",
 		"  change into home directory             <esc> ~",
 		"command history                          <esc> H",
-		"set sort order for files                 <esc> S",
+		"sort order for filenames                 <esc> S",
 		"re-read current directory                ctrl-R",
-		"locate file                              ctrl-F",
-		"  locate file using pattern              <esc> ctrl-F",
+		"locate file (substring)                  ctrl-F",
+		"locate file (pattern)                    <esc> ctrl-F",
 		"compare directories:                     <esc> =",
-		"select files:  +: select all             ctrl-G +",
-		"               -: deselect all           ctrl-G -",
+		"select files:  select all                ctrl-G +",
+		"               deselect all              ctrl-G -",
 		"               select using pattern      <esc> +",
 		"               deselect using pattern    <esc> -",
 		"               invert selection          <esc> *",
 		"configure CLEX                           <esc> C",
-		"display program version                  <esc> V",
+		"program version                          <esc> V",
 		"quit                                     <esc> Q"
 		/* must correspond with tab_mainmenu[] in control.c */
 	};
@@ -1168,18 +1187,13 @@ draw_line_compare(int ln)
 		"0: name, size, type (symbolic links ok)",
 		"1: name, size, type",
 		"2: name, size, type, ownership+permissions",
-		"3: name, size, type, ownership+permissions, contents",
+		"3: name, size, type, contents",
+		"4: name, size, type, ownership+permissions, contents",
 	};
 
 	putstr_trunc(description[ln],display.pancols,0);
 }
 
-static void
-draw_line_cfg_menu(int ln)
-{
-	putstr_trunc(panel_cfg_confirm.menu[ln],display.pancols,0);
-}
-
 static void
 draw_line_sort(int ln)
 {
@@ -1220,7 +1234,8 @@ draw_panel_line(int y)
 	else
 		addstr("  ");
 	if (ln < 0)
-		putstr_trunc("--- (leave this panel) ---",display.pancols,0);
+		putstr_trunc("--- (leave this panel / ctrl-C) ---",
+		  display.pancols,0);
 	else
 		(*draw_line)(ln);
 	if (panel->curs == ln) {
@@ -1238,28 +1253,12 @@ draw_panel(int optimize)
 	static int save_top, save_curs, save_ptype = PANEL_TYPE_NONE;
 	int y;
 
-	/* special case: panel is empty */
-	if (panel->cnt == 0) {
-		if (save_ptype != PANEL_TYPE_EMPTY) {
-			pos_panel = 1;
-			for (y = 0; y < display.panlines; y++) {
-				move(2 + y,0);
-				clrtoeol();
-			}
-			win_info();
-			save_ptype = PANEL_TYPE_EMPTY;
-		}
-		return;
-	}
-
 	if (panel->type != save_ptype) {
 		/* panel type has changed */
 		optimize = 0;
 		switch (save_ptype = panel->type) {
 		case PANEL_TYPE_CFG:
 			draw_line = draw_line_conf;		break;
-		case PANEL_TYPE_CFG_CONFIRM:
-			draw_line = draw_line_cfg_menu;	break;
 		case PANEL_TYPE_COMPARE:
 			draw_line = draw_line_compare;	break;
 		case PANEL_TYPE_COMPL:
@@ -1281,7 +1280,7 @@ draw_panel(int optimize)
 		case PANEL_TYPE_SORT:
 			draw_line = draw_line_sort;		break;
 		}
-		if (!panel->infoline)	/* the is not a typo */
+		if (!panel->infoline)	/* this is not a typo */
 			win_info();
 	}
 
