@@ -2,8 +2,7 @@
  *
  * CLEX File Manager
  *
- * Copyright (C) 1997-2000 Tempest s.r.o. http://www.tempest.sk
- * Copyright (C) 2001-2004 Vlado Potisk <vlado_potisk@clex.sk>
+ * Copyright (C) 2001-2005 Vlado Potisk <vlado_potisk@clex.sk>
  *
  * CLEX is free software without warranty of any kind; see the
  * GNU General Public License as set out in the "COPYING" document
@@ -97,7 +96,10 @@ cx_pan_pgdown(void)
 void
 pan_adjust(PANEL_DESC *p)
 {
-	CHECK_PANEL;
+	if (p->cnt == 0) {
+		p->top = p->curs = p->min;
+		return;
+	}
 
 	/* always in bounds */
 	LIMIT_MIN(p->top,p->min);
